@@ -1,8 +1,10 @@
 from accim.sim import accis
 accis.addAccis(
-    ScriptType='vrf',
-    Outputs='standard',
-    EnergyPlus_version='ep96',
+    ScriptType='vrf_mm',
+    Output_keep_existing=False,
+    Output_type='standard',
+    Output_freqs=['hourly'],
+    EnergyPlus_version='9.6',
     TempCtrl='temp',
     ComfStand=[0, 1, 2, 3],
     CAT=[1, 2, 3, 80, 90],
