@@ -20,9 +20,11 @@ class accimJob():
         addEMSSensorsBase, \
         addGlobVarList, \
         addIntVarList, \
-        addOutputVariablesBase, \
-        addOutputVariablesTimestep, \
-        addSimplifiedOutputVariables
+        addOutputVariablesStandard, \
+        addOutputVariablesSimplified, \
+        removeExistingOutputVariables, \
+        removeDuplicatedOutputVariables
+
     from accim.sim.accim_ExistingHVAC import \
         addForscriptSchExistHVAC
     from accim.sim.accim_ExistingHVAC_EMS import \
