@@ -47,6 +47,23 @@ def addBaseSchedules(self, verboseMode : bool = True):
             )
         if verboseMode:
             print("On Schedule has been added")
+    
+    if "TypOperativeTempControlSch" in [schedule.Name for schedule in self.idf1.idfobjects['Schedule:Compact']]:
+        if verboseMode:
+            print("TypOperativeTempControlSch Schedule already was in the model")
+    else:
+        self.idf1.newidfobject(
+            'Schedule:Compact',
+            Name="TypOperativeTempControlSch",
+            Schedule_Type_Limits_Name="Temperature",
+            Field_1='Through: 12/31',
+            Field_2='For: SummerDesignDay WinterDesignDay',
+            Field_3='Until: 24:00,0',
+            Field_4='For: AllOtherDays',
+            Field_5='Until: 24:00, 0.5',
+            )
+        if verboseMode:
+            print("TypOperativeTempControlSch Schedule has been added")
 
 
 def setAvailSchOn(self, verboseMode: bool = True):
@@ -69,7 +86,7 @@ def addVRFsystemSch(self, verboseMode: bool = True):
     Amend Schedule:Compact objects for VRFsystem.
 
     Add Schedule:Compact objects needed for VRFsystem to work,
-    other than FORSCRIPT Schedules.
+    other than AHST_Sch and ACST_Sch Schedules.
     """
     addVRFsystemSch_dict = {
         'On 24/7': 'Until: 24:00,1',
@@ -882,7 +899,7 @@ def addCurveObj(self, verboseMode: bool = True):
             print("HeatingCombRatio Curve:Linear Object has been added")
 
 
-def addDetHVACobj(self, EnergyPlus_version: str = None, verboseMode: bool = True):
+def addDetHVACobj(self, EnergyPlus_version: str = None, verboseMode: bool = True, TempCtrl: str = None):
     """Add Detailed HVAC objects for VRFsystem to work."""
     for zn in self.zonenames_orig:
         if 'VRF Outdoor Unit_'+zn in [i.Heat_Pump_Name
@@ -895,7 +912,7 @@ def addDetHVACobj(self, EnergyPlus_version: str = None, verboseMode: bool = True
                       ' AirConditioner:VariableRefrigerantFlow '
                       'Object already was in the model')
         else:
-            if EnergyPlus_version.lower() == 'ep96':
+            if EnergyPlus_version.lower() == '9.6' or '22' in EnergyPlus_version.lower():
                 self.idf1.newidfobject(
                     'AirConditioner:VariableRefrigerantFlow',
                     Heat_Pump_Name='VRF Outdoor Unit_'+zn,
@@ -1184,18 +1201,23 @@ def addDetHVACobj(self, EnergyPlus_version: str = None, verboseMode: bool = True
 
     del sizingzonelist
 
+    if TempCtrl == 'pmv':
+        supply_air_temp_input_method = 'SupplyAirTemperature'
+    elif TempCtrl.lower() == 'temp' or TempCtrl.lower() == 'temperature':
+        supply_air_temp_input_method = 'TemperatureDifference'
+
     for zn in self.zonenames_orig:
         self.idf1.newidfobject(
             'Sizing:Zone',
             Zone_or_ZoneList_Name=zn,
             Zone_Cooling_Design_Supply_Air_Temperature_Input_Method=
-            'TemperatureDifference',
+            supply_air_temp_input_method,
             Zone_Cooling_Design_Supply_Air_Temperature=14,
-            Zone_Cooling_Design_Supply_Air_Temperature_Difference=0.5,
+            Zone_Cooling_Design_Supply_Air_Temperature_Difference=5,
             Zone_Heating_Design_Supply_Air_Temperature_Input_Method=
-            'TemperatureDifference',
+            supply_air_temp_input_method,
             Zone_Heating_Design_Supply_Air_Temperature=50,
-            Zone_Heating_Design_Supply_Air_Temperature_Difference=0.5,
+            Zone_Heating_Design_Supply_Air_Temperature_Difference=5,
             Zone_Cooling_Design_Supply_Air_Humidity_Ratio=0.009,
             Zone_Heating_Design_Supply_Air_Humidity_Ratio=0.004,
             Design_Specification_Outdoor_Air_Object_Name=
@@ -1491,39 +1513,39 @@ def addDetHVACobj(self, EnergyPlus_version: str = None, verboseMode: bool = True
 def addForscriptSchVRFsystem(self, verboseMode: bool = True):
     """Add FORSCRIPT Schedules for each zone for VRFsystem."""
     for zn in self.zonenames:
-        if "FORSCRIPT_AHST_"+zn in [sch.Name
+        if "AHST_Sch_"+zn in [sch.Name
                                     for sch
                                     in self.idf1.idfobjects['Schedule:Compact']]:
             if verboseMode:
-                print('FORSCRIPT_AHST_'+zn+' Schedule already was in the model')
+                print('AHST_Sch_'+zn+' Schedule already was in the model')
         else:
             self.idf1.newidfobject(
                 'Schedule:Compact',
-                Name="FORSCRIPT_AHST_"+zn,
+                Name="AHST_Sch_"+zn,
                 Schedule_Type_Limits_Name="Any Number",
                 Field_1='Through: 12/31',
                 Field_2='For: AllDays',
                 Field_3='Until: 24:00,20'
                 )
             if verboseMode:
-                print('FORSCRIPT_AHST_'+zn+' Schedule has been added')
+                print('AHST_Sch_'+zn+' Schedule has been added')
 
-        if "FORSCRIPT_ACST_"+zn in [sch.Name
+        if "ACST_Sch_"+zn in [sch.Name
                                     for sch
                                     in self.idf1.idfobjects['Schedule:Compact']]:
             if verboseMode:
-                print('FORSCRIPT_ACST_'+zn+' Schedule already was in the model')
+                print('ACST_Sch_'+zn+' Schedule already was in the model')
         else:
             self.idf1.newidfobject(
                 'Schedule:Compact',
-                Name="FORSCRIPT_ACST_"+zn,
+                Name="ACST_Sch_"+zn,
                 Schedule_Type_Limits_Name="Any Number",
                 Field_1='Through: 12/31',
                 Field_2='For: AllDays',
                 Field_3='Until: 24:00,24'
                 )
             if verboseMode:
-                print('FORSCRIPT_ACST_'+zn+' Schedule has been added')
+                print('ACST_Sch_'+zn+' Schedule has been added')
 
     # allschedules=([i for i in self.idf1.idfobjects['Schedule:Compact']])
     # print(allschedules)
@@ -1544,9 +1566,9 @@ def addForscriptSchVRFsystem(self, verboseMode: bool = True):
             'ThermostatSetpoint:DualSetpoint',
             Name=self.zonenames_orig[i]+' Dual SP',
             Heating_Setpoint_Temperature_Schedule_Name=
-            "FORSCRIPT_AHST_"+self.zonenames[i],
+            "AHST_Sch_"+self.zonenames[i],
             Cooling_Setpoint_Temperature_Schedule_Name=
-            "FORSCRIPT_ACST_"+self.zonenames[i]
+            "ACST_Sch_"+self.zonenames[i]
             )
 
 
@@ -1610,3 +1632,4 @@ def checkVentIsOn(self, verboseMode: bool = True):
                 if d.Surface_Name.endswith('_Door')])
     for d in Dlist_2:
         d.Venting_Availability_Schedule_Name = 'On'
+
